<template>
<div>
  <a-card>
    <a-descriptions title="项目信息">
      <a-descriptions-item label="名称">
        {{ model.xmmc }}
      </a-descriptions-item>
      <a-descriptions-item label="编号">
        {{ model.xmbh }}
      </a-descriptions-item>
      <a-descriptions-item label="负责人">
        {{ userName }}
      </a-descriptions-item>

    </a-descriptions>
  </a-card>
  <a-card style='width: 100%;height: 200px;' class='custom-card'>
  <a-steps :current='current'>
    <a-popover slot='progressDot' slot-scope='{ index, status, title, description, prefixCls }'>
      <template slot='content'>
        <span>step {{ index }} status: {{ status }}</span>
      </template>
      <div :class='`${prefixCls}-icon-dot`' style='position: relative;'>
        <div class='step-normal'>
          {{ dataSource[index].milepostName }}
        </div>
      </div>

    </a-popover>
    <a-step v-for='(item,index) in dataSource' :key='index' :title="item.statu==1?'状态:已完成':'状态:未完成'" :description='item.completeDate' />

  </a-steps>
  </a-card>
  <div style='background-color: white'>
    <a-table
      ref="table"
      rowKey="id"
      size="middle"
      :columns="columns"
      :dataSource="dataSource"
      :pagination="ipagination"
      :loading="loading"
      @change="handleTableChange">
        <span slot="action" slot-scope="text, record">
          <a  @click="handleEdit(record)">
            <a-icon type="edit"/>
            编辑
          </a>

        </span>
    </a-table>
    <milestone-modal ref='modalForm' @ok="modalFormOk"></milestone-modal>
  </div>

</div>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { ajaxGetDictItems } from '@api/api'
import { getAction } from '@api/manage'
import MilestoneModal from '@views/pro/modules/MilestoneModal'
import { filterMultiDictText, initDictOptions } from '@comp/dict/JDictSelectUtil'
export default {
  name: 'MilestoneInfo',
  components: { MilestoneModal },
  mixins:[JeecgListMixin],
  data(){
    return{
      loading: false,
      disableMixinCreated:true,
      current:0,
      model:{},
      userDictOptions: [],
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: 'milepost',
          width: 120,
          align: "center",
        },
        {
          title: '字典名称',
          align: "left",
          dataIndex: 'milepostName',
        },

        {
          title: '状态',
          align: "center",
          width: 120,
          dataIndex: 'statu',
          customRender: function (t, r, index) {
            return  t==1?'已完成':'未完成';
          }
        },
        {
          title: '完成日期',
          align: "center",
          width: 120,
          dataIndex: 'completeDate',
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: "center",
          scopedSlots: {customRender: 'action'},
        }
      ],
      steps: [

        {
          title: '立项',
          content: '立项',
          statu: '状态:已完成',
          date: '2022年10月1日'
        },
        {
          title: '启动',
          content: '启动',
          statu: '状态:未完成',
          date: '2022年10月1日'
        },

        {
          title: '开发',
          content: '开发',
          statu: '状态:未完成',
          date: '2022年10月1日'
        },
        {
          title: '样机',
          content: '样机',
          statu: '状态:未完成',
          date: '2022年10月1日'
        },
        {
          title: '小批',
          content: '小批',
          statu: '状态:未完成',
          date: '2022年10月1日'
        }, {
          title: '量产',
          content: '量产',
          statu: '状态:未完成',
          date: '2022年10月1日'
        }
      ],
      url: {
        mileList: "/pro/mile/list",
        queryProById: "/pro/project/queryProById",
      },
    }
  },
  mounted() {
    this.initDictConfig()
    this.loadData()
    this.loadMilepost()
  },
  methods:{
    loadData(){
      if(!this.projectId) return
      let  params = {}
      params.id = this.projectId
      getAction(this.url.queryProById,params).then((res) => {
        console.info(res)
        if (res.success) {
          this.model = res.result
        }
      })
    },
    loadMilepost(){
      if(!this.projectId) return
      let  params = {}
      params.pro = this.projectId
      getAction(this.url.mileList,params).then((res) => {
        console.info(res)
        if (res.success) {
          this.dataSource = res.result.records
          let array =  this.dataSource.filter(item=>{
            return item.statu!=null && item.statu ==1
          })
          //计算当前里程碑
          var max = 0;
          if(array && array.length>0){
            max = Math.max.apply(Math, array.map(function(o) {return o.milepost}));
            max-=1
          }
          this.current = max;

        }
      })
    },
    initDictConfig() {
      //初始化字典
      initDictOptions('sys_user,realname,username').then((res) => {
        if (res.success) {
          this.$set(this.userDictOptions, 'username', res.result)
        }
      })
    },
    modalFormOk(){
      this.loadMilepost()
    }


  },
  computed: {
    //返回传过来的项目ID
    projectId: function () {
      return this.$route.params.id
    },
    userName: function () {
      return filterMultiDictText(this.userDictOptions['username'], this.model.xmfzr)
    },

  }
}
</script>

<style scoped>
.custom-card{
 padding-top: 60px;
}
.step-normal {
  min-width: 100px;
  height: 20px;
  position: absolute;
  transform: translateX(-50%);
  text-align: center;
  bottom: 20px;
  color: #4D9BE8;
}

.step-ok {
  width: 100px;
  height: 20px;
  position: absolute;
  transform: translateX(-50%);
  text-align: center;
  bottom: 30px;
  color: #42bc8e;
  font-size: 12px;
}


</style>